function OscRecord=oscreadtbs(fileName)

  NUMBER_COLUMNS = 6;
  COLUMN_PARAM_NAME = 1;
  COLUMN_X = 4;
  SIG_DIGITS = 4;
  MAX_EMPTY_ROWS = 5;

  [fCsv, msg] = fopen(fileName,"r");
  if (fCsv == -1)
    error(["Could not open file: " msg]);
  endif
  lineSplit = strsplit(fgetl(fCsv),",","collapsedelimiters",false);
  if (mod(size(lineSplit,2),NUMBER_COLUMNS) != 0)
    error("Incorrect input file format");
  endif
  nChannels = size(lineSplit,2)/NUMBER_COLUMNS;
  OscRecord.nChannels = nChannels;

  frewind(fCsv);
  nEmpty = 0;
  while (nEmpty <= MAX_EMPTY_ROWS)
    lineSplit = strsplit(fgetl(fCsv),",","collapsedelimiters",false);
    for iChannel=[1:nChannels]
      paramName = char(lineSplit((iChannel-1)*NUMBER_COLUMNS+COLUMN_PARAM_NAME));
      if (length(paramName) > 0)
        paramValue = char(lineSplit((iChannel-1)*NUMBER_COLUMNS+COLUMN_PARAM_NAME+1));
        switch (paramName)
          case "Record Length"
            OscRecord.Channels(iChannel).Params.length = str2num(paramValue);
          case "Sample Interval"
            OscRecord.Channels(iChannel).Params.dx = str2num(paramValue);
          case "Trigger Point"
            OscRecord.Channels(iChannel).Params.nTrigger = str2num(paramValue);
          case "Source"
            OscRecord.Channels(iChannel).Params.label = paramValue;
          case "Vertical Units"
            OscRecord.Channels(iChannel).Params.yUnit = paramValue;
          case "Vertical Scale"
            OscRecord.Channels(iChannel).Params.yScale = roundsigdgt(str2num(paramValue),SIG_DIGITS)*4/5;
          case "Vertical Offset"
            OscRecord.Channels(iChannel).Params.yOffset = roundsigdgt(str2num(paramValue),SIG_DIGITS);
          case "Horizontal Units"
            OscRecord.Channels(iChannel).Params.xUnit = paramValue;
          case "Horizontal Scale"
            OscRecord.Channels(iChannel).Params.xScale = roundsigdgt(str2num(paramValue),SIG_DIGITS);
          %case "Pt Fmt"
          case "Yzero"
            OscRecord.Channels(iChannel).Params.yZero = str2num(paramValue)*5/4;
          case "Note"
            OscRecord.Channels(iChannel).Params.note = paramValue;
        endswitch
        nEmpty = 0;
      else
        if (iChannel == 1)
          nEmpty = nEmpty+1;
        endif
      endif
    endfor
  endwhile

  fclose(fCsv);
    
  for iChannel=[1:nChannels]
      waveform = csvread(fileName, ...
          [0,(iChannel-1)*NUMBER_COLUMNS+COLUMN_X-1, ...
          OscRecord.Channels(iChannel).Params.length-1,(iChannel-1)*NUMBER_COLUMNS+COLUMN_X-1+1]);  
      OscRecord.Channels(iChannel).Values.x = waveform(:,1)';
      OscRecord.Channels(iChannel).Values.y = waveform(:,2)';
  endfor

endfunction
